@@ -288,8 +288,9 @@ class attributes:
             self.ax.set_title(self.title,
                               fontname=self.font if isinstance(self.title_font, type(None)) else self.title_font,
                               weight=self.title_weight,
-                              color=self.workspace_color if isinstance(self.title_color,
-                                                                       type(None)) else self.title_color,
+                              color=self.title_color if not isinstance(self.title_color, type(None))
+                                    else self.font_color if not isinstance(self.font_color, type(None))
+                                    else self.workspace_color,
                               size=self.title_size + self.font_size_increase)
             self.ax.title.set_position((0.5, self.title_y))
 
